#!/bin/bash

# Runs as ubuntu user.

OLDDIR=$(pwd)
cd ~

cp -r $OLDDIR/keys .ssh
chown $USER:$USER -R .ssh
chmod 500 .ssh/id_rsa

mkdir -p /home/$USER/{conf,logs,software,storage,workload}
mkdir -p /home/$USER/logs/{apps,hadoop}
sudo mount /dev/sdb /home/$USER/storage
sudo chown $USER:$USER -R /home/$USER/storage
mkdir -p /home/$USER/storage/data/local/{nm,tmp}
mkdir -p /home/$USER/storage/hdfs/{hdfs_dn_dirs,hdfs_nn_dir}

# Setup configuration
#wget http://pages.cs.wisc.edu/~akella/CS838/F15/assignment1/conf.tar.gz
tar xf $OLDDIR/conf.tar.gz
#wget http://pages.cs.wisc.edu/~akella/CS838/F15/assignment1/run.sh
cp -f $OLDDIR/run.sh .
chmod u+x run.sh
>instances
for i in $(seq 0 3); do
  hostname | sed s,node-.,node-$i, >>instances
done

# Set MASTER_IP in configuration to node-0
sed -i s,MASTER_IP,$(hostname | sed s,node-.,node-0,), /home/$USER/conf/*.xml

# Install hadoop sources
(cd ~/software;
  wget http://apache.arvixe.com/hadoop/common/hadoop-2.6.0/hadoop-2.6.0.tar.gz;
  tar xzf hadoop-*.tar.gz)

# Install TeZ sources
(cd ~/software;
  wget http://pages.cs.wisc.edu/~akella/CS838/F15/assignment1/tez-0.7.1-SNAPSHOT.tar.gz;
  wget http://pages.cs.wisc.edu/~akella/CS838/F15/assignment1/tez-0.7.1-SNAPSHOT-minimal.tar.gz
  tar xzf tez-0.7.1-SNAPSHOT-minimal.tar.gz)

# Install Hive sources
(cd ~/software;
  wget http://pages.cs.wisc.edu/~akella/CS838/F15/assignment1/hive-1.2.1.tar.gz;
  tar xzf hive-1.2.1.tar.gz)

if hostname | grep -q node-0; then
  ## ONLY MASTER NODE ##

  # Install Hive metastore.
  sudo debconf-set-selections <<< 'mysql-server mysql-server/root_password password'
  sudo debconf-set-selections <<< 'mysql-server mysql-server/root_password_again password'
  sudo apt-get -y install mysql-server
  sudo sed -i s,127.0.0.1,0.0.0.0, /etc/mysql/my.cnf
  sudo service mysql restart
  mysql -u root <<< "create database metastore"
  mysql -u root metastore <<< "create user 'hive'@'%' identified by 'hive'"
  mysql -u root metastore <<< "grant all privileges on metastore.* to 'hive'@'%' identified by 'hive'"
  mysql -u root metastore <<< "flush privileges"

  # Install TPC-DS / TPC-H workload.
  (cd ~/workload;
    wget http://pages.cs.wisc.edu/~akella/CS838/F15/assignment1/hive-tpcds-tpch-workload.tar.gz;
    tar xzf hive-tpcds-tpch-workload.tar.gz)
fi
